@@ -365,6 +365,12 @@ class ExerciseTracker:
                     return lite
     def useRoutine(self,reset_only=False,reset_note=False):
         try:
+            logMe=Prompt.__init2__(None,func=FormBuilderMkText,ptext="Log a comment in HealthLog(hl[default=True/Yes])?",helpText="yes or no/boolean",data="boolean")
+            if logMe is None:
+                return
+            elif logMe in ['d',]:
+                logMe=True
+
             start=datetime.now()
             rs=self.viewRoutine(returnable=True)
             if rs == None:
@@ -428,6 +434,10 @@ class ExerciseTracker:
                                     break
                                 exercise=session.query(Exercise).filter(Exercise.exid==i.exid).first()
                                 exercise.cdt=datetime.now()
+                                if logMe:
+                                    hl=HealthLog(Comments=f"{exercise.Name}:exid:{i}\nstarted! {datetime.now().ctime()}")
+                                    session.add(hl)
+                                    session.commit()
                                 if exercise.CurrentRep < exercise.Reps:
                                     setattr(exercise,"CurrentRep",getattr(exercise,"CurrentRep")+1)
                                 else:
